#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-byte-order
version:              0.1.7
visibility:           public
id:                   network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
key:                  network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Network byte order utilities
description:          Peek and poke functions for network byte order.
category:             Network
abi:                  b94642efa402feb8d1d9960730cc2b8d
exposed:              True
exposed-modules:      Network.ByteOrder
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-byte-order-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-byte-order-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-byte-order-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-byte-order
hs-libraries:         HSnetwork-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:
    /usr/share/doc/haskell-network-byte-order/html/network-byte-order.haddock

haddock-html:         /usr/share/doc/haskell-network-byte-order/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

